@@ -1,21 +1,24 @@
-#!/usr/bin/perl
-
 package Catalyst::Plugin::Session::Store::Dummy;
 use base qw/Catalyst::Plugin::Session::Store/;
 
 use strict;
 use warnings;
 
+our $VERSION = '0.42';
+$VERSION =~ tr/_//d;
+
 my %store;
 
 sub get_session_data {
-    my ( $c, $sid ) = @_;
-    $store{$sid};
+    my ( $c, @keys ) = @_;
+    @store{@keys};
 }
 
 sub store_session_data {
-    my ( $c, $sid, $data ) = @_;
-    $store{$sid} = $data;
+    my $c = shift;
+    my %data = @_;
+
+    @store{ keys %data } = values %data;
 }
 
 sub delete_session_data {
